WindowsVersion class

Constructors

WindowsVersion({int majorVersion = 0, int minorVersion = 0, int buildNumber = 0, String servicePack = '', int servicePackMajor = 0, int servicePackMinor = 0, WindowsType type = WindowsType.unknown})

Properties

buildNumber int
final
hashCode int
The hash code for this object.
no setterinherited
majorVersion int
final
minorVersion int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
servicePack String
final
servicePackMajor int
final
servicePackMinor int
final
type WindowsType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited